Struct compactmap::wrapped::CompactMap
[−]
[src]
pub struct CompactMap<K: Into<usize> + From<usize>, V> { /* fields omitted */ }
Special version of CompactMap that uses your usize-equivalent types as keys
You are expected to use newtype-style structs like struct MyToken(usize); for this
If needed, you can cheat with into_unwrapped, unwrapped and so on.
For example, this will fail:
#[macro_use] extern crate compactmap; fn main() { use compactmap::wrapped::CompactMap; declare_compactmap_token!(Mom); declare_compactmap_token!(Lol); let mut m1: CompactMap<Mom, u64> = CompactMap::new(); let mut m2: CompactMap<Lol, u64> = CompactMap::new(); let q = m1.insert(123); m2.remove(q); // expected type `main::Lol`, found type `main::Mom` }
Methods
impl<K: Into<usize> + From<usize>, V> CompactMap<K, V>[src]
fn into_unwrapped(self) -> CompactMap<V>[src]
Extract underlying unwrapped map
fn from_unwrapped(s: CompactMap<V>) -> Self[src]
Wrap the map. You are responsible that it is the correct one
fn unwrapped(&self) -> &CompactMap<V>[src]
Temporarily use the map without the safety wrapper
fn unwrapped_mut(&mut self) -> &mut CompactMap<V>[src]
Temporarily use the map without the safety wrapper
impl<K: Into<usize> + From<usize>, V> CompactMap<K, V>[src]
fn new() -> Self[src]
fn with_capacity(capacity: usize) -> Self[src]
fn capacity(&self) -> usize[src]
fn reserve(&mut self, len: usize)[src]
fn reserve_exact(&mut self, len: usize)[src]
fn clear(&mut self)[src]
fn is_empty_slow(&self) -> bool[src]
fn insert(&mut self, v: V) -> K[src]
fn remove(&mut self, i: K) -> Option<V>[src]
fn get(&self, i: K) -> Option<&V>[src]
fn get_mut(&mut self, i: K) -> Option<&mut V>[src]
fn iter(&self) -> Iter<K, V>[src]
Returns an iterator visiting all key-value pairs in unspecified order.
The iterator's element type is (K, &'r V).
fn iter_mut(&mut self) -> IterMut<K, V>[src]
Returns an iterator visiting all key-value pairs in unspecified order,
with mutable references to the values.
The iterator's element type is (K, &'r mut V)
fn into_iter(self) -> IntoIter<K, V>[src]
Returns an iterator visiting all key-value pairs in unspecified order,
the keys, consuming the original CompactMap.
The iterator's element type is (K, V).
fn keys(&self) -> Keys<K, V>[src]
Returns an iterator visiting all keys in some order.
The iterator's element type is K.
fn values(&self) -> Values<V>[src]
fn values_mut(&mut self) -> ValuesMut<V>[src]
fn len_slow(&self) -> usize[src]
fn shrink_to_fit(&mut self)[src]
fn drain(&mut self) -> Drain<K, V>[src]
Returns an iterator visiting all key-value pairs in ascending order of
the keys, emptying (but not consuming) the original CompactMap.
The iterator's element type is (K, V). Keeps the allocated memory for reuse.